package server;

import java.io.IOException;
import java.nio.ByteBuffer;
import java.text.MessageFormat;
import java.util.Arrays;

import org.eclipse.jetty.websocket.api.Session;
import org.eclipse.jetty.websocket.api.WebSocketListener;

public class WebSocketObject implements WebSocketListener
{
   private Session outbound;
   private final MessageFormat webSocketClosed = new MessageFormat(
            "onWebSocketClose: status = {0} reason = {1}");
   private final MessageFormat webSocketBinary = new MessageFormat(
            "onWebSocketBinary: payload length = {0}, offset = {1}, length = {2}");

   @Override
   public void onWebSocketClose(int statusCode, String reason)
   {
      outbound = null;
      System.err.println(webSocketClosed.format(new Object[] {statusCode, reason}));
   }

   @Override
   public void onWebSocketConnect(Session newSession)
   {
      outbound = newSession;
   }

   @Override
   public void onWebSocketError(Throwable cause)
   {
      cause.printStackTrace(System.err);
   }

   @Override
   public void onWebSocketBinary(byte[] payload, int offset, int len)
   {
      System.err.println(webSocketBinary.format(new Object[]{payload.length, offset, len}));
      if (payload.length == 256)
      {
         boolean send = true;
         for (int i=255; i>0; i--)
         {
            if (payload[i] != (byte) 0xFF)
            {
               send = false;
            }
         }
         if (send)
         {
            send = false;
            byte[] buffer = new byte[32 * 1024 * 1024 * 2];
            Arrays.fill(buffer, (byte) 0xFF);
            try
            {
               outbound.getRemote().sendBytes(ByteBuffer.wrap(buffer));
            }
            catch (IOException e)
            {
               e.printStackTrace();
            }
         }
         else
         {
            send = true;
            for (int i=255; i>0; i--)
            {
               if (payload[i] != (byte)0xEF)
               {
                  send = false;
               }
            }
         }
         if (send)
         {
            byte[] buffer1 = new byte[32 * 1024 * 1024];
            Arrays.fill(buffer1, (byte) 0xEF);
            byte[] buffer2 = new byte[32];
            Arrays.fill(buffer2, (byte) 0xFF);
            try
            {
//               outbound.getRemote().sendPartialBytes(ByteBuffer.wrap(buffer1), false);
//               outbound.getRemote().sendPartialBytes(ByteBuffer.wrap(buffer1), true);
//               outbound.getRemote().sendBytes(ByteBuffer.wrap(buffer1));
               outbound.getRemote().sendPing(ByteBuffer.wrap(buffer2));
            }
            catch (IOException e)
            {
               e.printStackTrace();
            }
         }
      }
   }

   @Override
   public void onWebSocketText(String textMessage)
   {
   }

}
