/**
 * 
 */
function WebSocketClient(path, mainFormId, feedbackId)
{
   var me = {};
   var ws;
   var connected  = false;
   var fileLoaded = false;
   var buffer;
   var mainForm;
   var feedback;
   
   me.init = function()
   {
      mainForm = document.getElementById(mainFormId);
      mainForm.fileInput.onchange = loadFile;
      mainForm.reset.onclick = clear;
      mainForm.getButton.onclick = get;
      mainForm.getPartial.onclick = getPartial;
      feedback = document.getElementById(feedbackId);
      reportFeedback("loaded " + path);
      ws = new WebSocket(path);

      // on web socket open
      ws.onopen = function()
      {
         ws.binaryType = 'arraybuffer';
         connected = true;
         reportFeedback("websocket connected " + path);
      };
      // on web socket close
      ws.onclose = function(evt)
      {
         connected = false;
         reportFeedback("websocket closed code=" + evt.code + " reason=" + evt.reason);
      };
      // on web socket error
      ws.onerror = function(evt)
      {
         connected = false;
         reportFeedback("websocket error " + evt.detail);
      };
      // on web socket message
      ws.onmessage = function(evt)
      {
         var data = evt.data;
         
         if (data instanceof ArrayBuffer)
         {
            // binary messages
            var message = new Uint8Array(data);
            reportFeedback("websocket on message " + message.byteLength);
         }
      };
   };
   
   me.submit = function()
   {
      if (connected && fileLoaded)
      {
         ws.send(buffer);
         reportFeedback("send " + buffer.byteLength);
      }
      return false;
   };
   
   function clear(event)
   {
      fileLoaded = false;
   };
   
   function get(event)
   {
      if (connected)
      {
         var msg = new ArrayBuffer(256);
         var msgView = new Uint8Array(msg);
         msgView.fill(0xff);
         ws.send(msg);
         reportFeedback("Get a message from the server");
      }
   };
   
   function getPartial(event)
   {
      if (connected)
      {
         var msg = new ArrayBuffer(256);
         var msgView = new Uint8Array(msg);
         msgView.fill(0xef);
         ws.send(msg);
         reportFeedback("Get a message of a partial type from the server");
      }
   };

   function loadFile(event)
   {
      var reader = new FileReader();
      reader.onload = function(evt)
      {
         fileLoaded = true;
         buffer = evt.target.result;
         reportFeedback("file loaded " + buffer.byteLength);
      };
      reader.onerror = function(evt)
      {
         fileLoaded = false;
         reportFeedback("file loading error " + evt.target.error);
      }
      reportFeedback('New file selected ' + event.target.files[0]);
      reader.readAsArrayBuffer(event.target.files[0]);
   };
   
   function reportFeedback(msg)
   {
      if (feedback)
      {
         var textEl = document.createTextNode(msg);
         var div = document.createElement("div");
         div.appendChild(textEl);
         feedback.appendChild(div);
      }
   }
   
   return me;
}